2023-11-15 Version: 1.0.2
- Generated python2 2018-07-24 for Trademark.

2023-10-16 Version: 1.0.1
- Generated python2 2018-07-24 for Trademark.

2021-10-21 Version: 1.0.0
- Supported trademark api.

